pyqode.python.panels package
============================

Module contents
---------------

.. automodule:: pyqode.python.panels


Classes
-------

QuickDocPanel
+++++++++++++

.. autoclass:: pyqode.python.panels.QuickDocPanel
    :members:
    :undoc-members:
    :show-inheritance:


SymbolBrowserPanel
++++++++++++++++++

.. autoclass:: pyqode.python.panels.SymbolBrowserPanel
    :members:
    :undoc-members:
    :show-inheritance:
